@@ -1,5 +1,5 @@
 use DBIx::Squirrel database_entities => [qw/db get_artist_by_id/];
-use DBIx::Squirrel::Transform::IO         qw/stdout/;
+use DBIx::Squirrel::Transform::IO         qw/stderr/;
 use DBIx::Squirrel::Transform::JSON::Syck qw/as_json/;
 
 db do {
@@ -15,11 +15,11 @@ db do {
 };
 
 get_artist_by_id do {
-    db->results("SELECT * FROM artists WHERE ArtistId=? LIMIT 1" => as_json(), stdout("%s\n"))->reset({});
+    db->results("SELECT * FROM artists WHERE ArtistId=? LIMIT 1")->slice({});
 };
 
 foreach my $id (1 .. 9) {
-    get_artist_by_id($id)->single;
+    get_artist_by_id($id => as_json() => stderr("%s\n"))->single;
 }
 
 db->disconnect();
